@@ -125,6 +125,7 @@ private: // Private variables
      */
     KIO::AuthInfo *mPublicKeyAuthInfo = nullptr;
 
+#if !defined(HAVE_SFTP_AIO)
     /**
      * GetRequest encapsulates several SFTP get requests into a single object.
      * As SFTP messages are limited to MAX_XFER_BUF_SIZE several requests
@@ -162,7 +163,7 @@ private: // Private variables
          * @param data the array into which the data should be saved (it should be empty).
          * @return 0 on EOF or timeout, -1 on error and the number of bytes read otherwise.
          */
-        int readChunks(QByteArray &data);
+        size_t readChunks(QByteArray &data);
 
     private:
         struct Request {
@@ -179,6 +180,7 @@ private: // Private variables
         ushort m_maxPendingRequests;
         QQueue<Request> m_pendingRequests;
     };
+#endif // HAVE_SFTP_AIO
 
     struct ReadResponse {
         // NOTE: older GCC versions have trouble when using structs that were aggregate initialized and crash on
@@ -208,7 +210,7 @@ private: // Private variables
 private: // private methods
     int authenticateKeyboardInteractive(KIO::AuthInfo &info);
 
-    Q_REQUIRED_RESULT Result reportError(const QUrl &url, const int err);
+    Q_REQUIRED_RESULT Result reportError(const QUrl &url, int err);
 
     Q_REQUIRED_RESULT Result createUDSEntry(SFTPAttributesPtr sb, KIO::UDSEntry &entry, const QByteArray &path, const QString &name, int details);
 
